import * as eks from 'aws-cdk-lib/aws-eks';
import { Construct } from 'constructs';
export interface VpcCniAddonProps extends EksManagedAddonProps {
    readonly addonVersion?: VpcCniAddonVersion;
}
interface EksManagedAddonProps {
    readonly cluster: eks.Cluster;
    readonly addonVersion?: AddonVersion;
    readonly resolveConflicts?: boolean;
    readonly namespace?: string;
}
declare abstract class AddonVersion {
    readonly version: string;
    static of(version: string): void;
    constructor(version: string);
}
export declare class VpcCniAddonVersion extends AddonVersion {
    /**
     * vpc-cni version 1.6.3
     */
    static readonly V1_6_3: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.7.5
     */
    static readonly V1_7_5: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.7.6
     */
    static readonly V1_7_6: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.7.9
     */
    static readonly V1_7_9: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.7.10
     */
    static readonly V1_7_10: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.8.0
     */
    static readonly V1_8_0: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.9.0
     */
    static readonly V1_9_0: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.9.1
     */
    static readonly V1_9_1: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.9.3
     */
    static readonly V1_9_3: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.10.1
     */
    static readonly V1_10_1: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.10.2
     */
    static readonly V1_10_2: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.10.3
     */
    static readonly V1_10_3: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.11.0
     */
    static readonly V1_11_0: VpcCniAddonVersion;
    /**
     * Custom add-on version
     * @param version custom add-on version
     */
    static of(version: string): VpcCniAddonVersion;
}
interface EksManagedAddonAbstractProps {
    readonly cluster: eks.Cluster;
    readonly addonName: string;
    readonly addonVersion?: AddonVersion;
    readonly resolveConflicts?: boolean;
    readonly serviceAccountName?: string;
    readonly awsManagedPolicyName?: string;
    readonly namespace?: string;
}
declare abstract class EksManagedAddonAbstract extends eks.CfnAddon {
    protected constructor(scope: Construct, id: string, props: EksManagedAddonAbstractProps);
}
export declare class VpcEniAddon extends EksManagedAddonAbstract {
    /**
     *
     */
    constructor(scope: Construct, id: string, props: VpcCniAddonProps);
}
export {};
